//----------------------------------------------------------------------//
//
//	Copyright (c) 2017 BeeBeans Technologies All rights reserved
//
//		System		: independent
//
//		Module		: REBOOT
//
//		Description	: FPGA REBOOT
//
//		file		: REBOOT.v
//
//		Note		: for 7series
//
//		history	:
//			170726	------		Created by M.Ishiwata
//			171204	------		Modified by K.Iwase
//
//----------------------------------------------------------------------//
`default_nettype none
module
	REBOOT		#(
		parameter	[ 7:0]	CLOCK_FREQUENCY = 200		// CLK_IN Frequency(MHz) > 2MHz
	)(
		input	wire			CLK_IN,					// System Clock
		input	wire			CFG_CLK_IN,				// Reconfig Clock =< 100MHz
		input	wire			RESET_IN,				// Reset
		input	wire			REBOOT_IN				// Reboot Request
	);

	reg				REBOOT_START;
	reg				REBOOT_STOP;
	reg		[24:0]	REBOOT_CNT;
	reg		[ 8:0]	REBOOT_nEN;
	reg		[31:0]	REBOOT_CMD[0:8];
	wire	[31:0]	REBOOT_SWP;
	wire	[31:0]	REBOOT_DAT;


	always@(posedge CLK_IN or posedge RESET_IN)begin
		if (RESET_IN) begin
			REBOOT_START	<= 1'b0;
			REBOOT_STOP		<= 1'b1;
		end else begin
			REBOOT_START	<= REBOOT_START | REBOOT_IN;
			REBOOT_STOP		<= ~REBOOT_START;
		end
	end
	
	always@(posedge CFG_CLK_IN or posedge REBOOT_STOP)begin
		if (REBOOT_STOP) begin
			REBOOT_CNT[24:0]	<= {1'b0,24'd100000};
		end else begin
			REBOOT_CNT[24:0]	<= REBOOT_CNT[24:0] - {24'd0,~REBOOT_CNT[24]};
		end
	end

	initial			REBOOT_nEN[8:0]	= 9'b1_0000_0000;
	initial			REBOOT_CMD[8]	= 32'hffff_ffff;
	always@(posedge CFG_CLK_IN)begin
		REBOOT_nEN[8:0]		<= REBOOT_CNT[24]?	{REBOOT_nEN[7:0],1'b1}:		9'b1_0000_0000;
		REBOOT_CMD[0]		<= REBOOT_CNT[24]?	32'h2000_0000:				32'h2000_0000;	// NOOP;
		REBOOT_CMD[1]		<= REBOOT_CNT[24]?	REBOOT_CMD[0]:				32'h0000_000F;	// CMD = IPROG
		REBOOT_CMD[2]		<= REBOOT_CNT[24]?	REBOOT_CMD[1]:				32'h3000_8001;	// write CMD length:1
		REBOOT_CMD[3]		<= REBOOT_CNT[24]?	REBOOT_CMD[2]:				32'h0000_0000;	// WBSTAR data
		REBOOT_CMD[4]		<= REBOOT_CNT[24]?	REBOOT_CMD[3]:				32'h3002_0001;	// write WBSTAR length:1
		REBOOT_CMD[5]		<= REBOOT_CNT[24]?	REBOOT_CMD[4]:				32'h2000_0000;	// NOOP
		REBOOT_CMD[6]		<= REBOOT_CNT[24]?	REBOOT_CMD[5]:				32'hAA99_5566;	// SYNC Word
		REBOOT_CMD[7]		<= REBOOT_CNT[24]?	REBOOT_CMD[6]:				32'hffff_ffff;	// Dummy Word
		REBOOT_CMD[8]		<= REBOOT_CNT[24]?	REBOOT_CMD[7]:				32'hffff_ffff;
	end

	assign	REBOOT_SWP[31:0]	= REBOOT_CMD[8];
	assign	REBOOT_DAT[31:24]	= {REBOOT_SWP[24],REBOOT_SWP[25],REBOOT_SWP[26],REBOOT_SWP[27],REBOOT_SWP[28],REBOOT_SWP[29],REBOOT_SWP[30],REBOOT_SWP[31]};
	assign	REBOOT_DAT[23:16]	= {REBOOT_SWP[16],REBOOT_SWP[17],REBOOT_SWP[18],REBOOT_SWP[19],REBOOT_SWP[20],REBOOT_SWP[21],REBOOT_SWP[22],REBOOT_SWP[23]};
	assign	REBOOT_DAT[15: 8]	= {REBOOT_SWP[ 8],REBOOT_SWP[ 9],REBOOT_SWP[10],REBOOT_SWP[11],REBOOT_SWP[12],REBOOT_SWP[13],REBOOT_SWP[14],REBOOT_SWP[15]};
	assign	REBOOT_DAT[ 7: 0]	= {REBOOT_SWP[ 0],REBOOT_SWP[ 1],REBOOT_SWP[ 2],REBOOT_SWP[ 3],REBOOT_SWP[ 4],REBOOT_SWP[ 5],REBOOT_SWP[ 6],REBOOT_SWP[ 7]};

	ICAPE2	#(
		.ICAP_WIDTH		("X32")
	)
	ICAPE2	(
		.CLK			(CFG_CLK_IN),			// ICAPE2 Clock =<100MHz
		.CSIB			(REBOOT_nEN[8]),		// ICAPE2 Not Enable	1:Not Select  0:Select
		.RDWRB			(1'b0),					// ICAPE2 Read(1) Write(0) Select
		.I				(REBOOT_DAT[31:0]),		// ICAPE2 Write Data[31:0]
		.O				()						// ICAPE2 Read Data[31:0]
	);
endmodule
`default_nettype wire
