/*******************************************************************************
*                                                                              *
* System      : SiTCP Evaluation Board                                         *
* Block       : User FPGA I/F                                                  *
* Module      : SiTCP_EV_USRIF                                                 *
* Version     : v 0.0.0 2008/10/08 18:40                                       *
*                                                                              *
* Description : Coincidence Unit                                               *
*                                                                              *
* Designer    : Tomohisa Uchida                                                *
*                                                                              *
*                Copyright (c) 2008 Tomohisa Uchida                            *
*                All rights reserved                                           *
*                                                                              *
*******************************************************************************/
module SiTCP_EV_USRIF(
// System
	CLK					,	// in	: System clock
	RST					,	// in	: System reset
// SiTCP IF
	OPEN_ACK			,	// in	: Acknowledge for open (=Socket busy)
	CLOSE_REQ			,	// in	: Connection close
	CLOSE_ACK			,	// out	: Acknowledge for close
	RX_FIFO_FILL		,	// out	: Fill level[15:0]
	RX_FIFO_WR			,	// in	: Write enable
	RX_FIFO_DATA		,	// in	: Write data[7:0]
	TX_FIFO_AFULL		,	// in	: Almost full flag
	TX_FIFO_WR			,	// out	: Write enable
	TX_FIFO_DATA		,	// out	: Write data[7:0]
// User I/F
	USR_CLK				,	// in	: Clock
	USR_ACTIVE			,	// out	: TCP established
	USR_CLOSE_REQ		,	// out	: Request to close a TCP Connection
	USR_CLOSE_ACK		,	// in	: Acknowledge for USR_CLOSE_REQ
	// TCP Tx
	USR_TX_AFULL		,	// out	: Almost full flag of a TCP Tx FIFO
	USR_TX_WE			,	// in	: TCP Tx Data write enable
	USR_TX_WD			,	// in	: TCP Tx Data[7:0]
	// TCP Rx
	USR_RX_EMPTY		,	// out	: Empty flag of a TCP RX flag
	USR_RX_RE			,	// in	: TCP Rx Data Read enable
	USR_RX_RV			,	// out	: TCP Rx data valid
	USR_RX_RD				// out	: TCP Rx data[7:0]
);

//-------- Input/Output -------------
	input			CLK				;
	input			RST				;

	input			OPEN_ACK		;
	input			CLOSE_REQ		;
	output			CLOSE_ACK		;
	output	[15:0]	RX_FIFO_FILL	;
	input			RX_FIFO_WR		;
	input	[7:0]	RX_FIFO_DATA	;
	input			TX_FIFO_AFULL	;
	output			TX_FIFO_WR		;
	output	[7:0]	TX_FIFO_DATA	;

	input			USR_CLK			;
	output			USR_ACTIVE		;
	output			USR_CLOSE_REQ	;
	input			USR_CLOSE_ACK	;
	output			USR_TX_AFULL	;
	input			USR_TX_WE		;
	input	[7:0]	USR_TX_WD		;
	output			USR_RX_EMPTY	;
	input			USR_RX_RE		;
	output			USR_RX_RV		;
	output	[7:0]	USR_RX_RD		;

//------ output signals -----
	wire			CLOSE_ACK		;
	wire	[15:0]	RX_FIFO_FILL	;
	wire			TX_FIFO_WR		;
	wire	[7:0]	TX_FIFO_DATA	;
	wire			USR_ACTIVE		;
	wire			USR_CLOSE_REQ	;
	wire			USR_TX_AFULL	;
	wire			USR_RX_EMPTY	;
	wire			USR_RX_RV		;
	wire	[7:0]	USR_RX_RD		;



//------------------------------------------------------------------------------
endmodule
